@@ -1,5 +1,6 @@
 '''A module to finds all kinds of primes.'''
 from time import time
+from math import log
 
 NUMPY_ENABLED = True
 try:
@@ -78,20 +79,6 @@ def find_twins(n):
 
     return twin_primes
 
-def find_reverse(n):
-    '''
-    Return a dict that has all reverse primes below n.
-    '''
-    _check_num(n)
-    primes = all_primes(n)
-    reverse_primes = {}
-    for ix, xp in enumerate(primes):
-        reverse_num = int(str(xp)[::-1])
-        if is_prime(reverse_num) and xp > 10:
-            reverse_primes[xp] = reverse_num
-
-    return reverse_primes
-
 def find_palindromes(n):
     '''
     Return a list that has all palindromes primes below n.
@@ -106,6 +93,25 @@ def find_palindromes(n):
 
     return palin_primes
 
+def find_reverse(n):
+    '''
+    Return a dict that has all reverse primes below n.
+    '''
+    _check_num(n)
+    primes = all_primes(n)
+    reverse_primes = {}
+    for ix, xp in enumerate(primes):
+        reverse_num = int(str(xp)[::-1])
+        if is_prime(reverse_num) and xp > 10:
+            reverse_primes[xp] = reverse_num
+
+    palin_primes = find_palindromes(n)
+    for x in palin_primes:
+        if reverse_primes.get(x):
+            reverse_primes.pop(x)
+
+    return reverse_primes
+
 def find_square_palindromes(n):
     '''
     Return a dict that has all square palindrome primes below n.
@@ -146,14 +152,25 @@ def find_arithmetic_prime_progressions(n):
 
     return arithmetic_prime_list
 
+def find_mersenne_primes(n):
+    _check_num(n)
+    primes = set(all_primes(n))
+    result = []
+    for i in range(2, int(log(n + 1, 2)) + 1):
+        result.append(2**i - 1)
+
+    mersenne_primes = primes.intersection(result)
+    return sorted(list(mersenne_primes))
+
 def main():
     '''A test of this module.'''
     start_tm = time()
     print(f'Twin primes: {find_twins(4750)}\n')
-    print(f'Reverse primes: {find_reverse(3000)}\n')
     print(f'Palindome primes: {find_palindromes(20000)}\n')
+    print(f'Reverse primes: {find_reverse(3000)}\n')
     print(f'Square palindome primes: {find_square_palindromes(500)}\n')
-    print(f'Arithmetic prime progressions: {find_arithmetic_prime_progressions(125)}')
+    print(f'Arithmetic prime progressions: {find_arithmetic_prime_progressions(125)}\n')
+    print(f'Mersenne Primes: {find_mersenne_primes(525000)}')
     end_tm = time()
     print(f'Time: {round(end_tm - start_tm, 12)} seconds.')
 
